#[repr(C, packed(1))]pub struct MOSComplexInterfaceAdapter6526 {
pub port_a: RW<GameController>,
pub port_b: RW<GameController>,
pub data_direction_port_a: RW<u8>,
pub data_direction_port_b: RW<u8>,
pub timer_a: RW<u16>,
pub timer_b: RW<u16>,
pub time_of_day: TimeOfDay,
pub serial_shift: RW<u8>,
pub interrupt: RW<u8>,
pub control_a: RW<u8>,
pub control_b: RW<u8>,
}Expand description
Registers for the MOS Tehnology Complex Interface Adapter 6526
The CIA served as an I/O port controller for the 6502 family of microprocessors, providing for parallel and serial I/O capabilities as well as timers and a Time-of-Day (TOD) clock. The device’s most prominent use was in the Commodore 64 and Commodore 128(D), each of which included two CIA chips.
Fields
port_a: RW<GameController>port_b: RW<GameController>data_direction_port_a: RW<u8>data_direction_port_b: RW<u8>timer_a: RW<u16>timer_b: RW<u16>time_of_day: TimeOfDayserial_shift: RW<u8>interrupt: RW<u8>control_a: RW<u8>control_b: RW<u8>Auto Trait Implementations
impl !Freeze for MOSComplexInterfaceAdapter6526
impl !RefUnwindSafe for MOSComplexInterfaceAdapter6526
impl !Sync for MOSComplexInterfaceAdapter6526
impl Send for MOSComplexInterfaceAdapter6526
impl Unpin for MOSComplexInterfaceAdapter6526
impl UnsafeUnpin for MOSComplexInterfaceAdapter6526
impl UnwindSafe for MOSComplexInterfaceAdapter6526